from typing import Optional, Literal

from pydantic import BaseModel


class AAIOResponse(BaseModel):
    type: Literal['error', 'success']
    code: Optional[int] = None
    message: Optional[str] = None



from typing import Optional

from aaio.types.response import AAIOResponse


class Balance(AAIOResponse):
    balance: Optional[float] = None
    referral: Optional[float] = None
    hold: Optional[float] = None



from typing import Literal, Optional

from aaio.types.response import AAIOResponse


class CreatePayoff(AAIOResponse):
    id: Optional[str] = None
    my_id: Optional[str] = None
    method: Optional[str] = None
    wallet: Optional[str] = None
    amount: Optional[float] = None
    amount_in_currency: Optional[float] = None
    amount_currency: Optional[str] = None
    amount_rate: Optional[float] = None
    amount_down: Optional[float] = None
    commission: Optional[float] = None
    commission_type: Optional[int] = None
    status: Optional[Literal['in_process', 'cancel', 'success']] = None



from typing import Literal, Optional

from aaio.types.response import AAIOResponse


class PaymentInfo(AAIOResponse):
    id: Optional[str] = None
    order_id: Optional[str] = None
    desc: Optional[str] = None
    merchant_id: Optional[str] = None
    merchant_domain: Optional[str] = None
    method: Optional[str] = None
    amount: Optional[float] = None
    currency: Optional[Literal['RUB', 'UAH', 'EUR', 'USD']] = None
    profit: Optional[float] = None
    commission: Optional[float] = None
    commission_client: Optional[float] = None
    commission_type: Optional[str] = None
    email: Optional[str] = None
    status: Optional[Literal['in_process', 'success', 'expired', 'hold']] = None
    date: Optional[str] = None
    expired_date: Optional[str] = None
    complete_date: Optional[str] = None
    us_vars: Optional[dict[str, str]] = None



from typing import Optional

from pydantic import BaseModel

from aaio.types.response import AAIOResponse


class PayoffMethod(BaseModel):
    name: str
    min: float
    max: float
    commission_percent: float
    commission_sum: float


class PayoffMethods(AAIOResponse):
    list: Optional[dict[str, PayoffMethod]] = None



from typing import Literal, Optional

from aaio.types.response import AAIOResponse


class PayoffInfo(AAIOResponse):
    id: Optional[str] = None
    my_id: Optional[str] = None
    method: Optional[str] = None
    wallet: Optional[str] = None
    amount: Optional[float] = None
    amount_down: Optional[float] = None
    commission: Optional[float] = None
    commission_type: Optional[Literal[0, 1]] = None
    status: Optional[Literal['in_process', 'cancel', 'success']] = None
    cancel_message: Optional[str] = None
    date: Optional[str] = None
    complete_date: Optional[str] = None



from typing import Optional

from aaio.types.response import AAIOResponse


class PayoffRates(AAIOResponse):
    USD: Optional[float] = None
    UAH: Optional[float] = None
    USDT: Optional[float] = None
    BTC: Optional[float] = None
